==> zio-aws-workspaces_2.13-5.17.182.1-sources.jar: zio/aws/workspaces/model/Tag.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.{TagValue, TagKey}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Tag(key: TagKey, value: Optional[TagValue] = Optional.Absent) {
  def buildAwsValue(): software.amazon.awssdk.services.workspaces.model.Tag = {
    import Tag.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.Tag
      .builder()
      .key(TagKey.unwrap(key): java.lang.String)
      .optionallyWith(
        value.map(value => TagValue.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly: zio.aws.workspaces.model.Tag.ReadOnly =
    zio.aws.workspaces.model.Tag.wrap(buildAwsValue())
}
object Tag {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.workspaces.model.Tag] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.Tag =
      zio.aws.workspaces.model.Tag(key, value.map(value => value))
    def key: TagKey
    def value: Optional[TagValue]
    def getKey: ZIO[Any, Nothing, TagKey] = ZIO.succeed(key)
    def getValue: ZIO[Any, AwsError, TagValue] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.Tag
  ) extends zio.aws.workspaces.model.Tag.ReadOnly {
    override val key: TagKey =
      zio.aws.workspaces.model.primitives.TagKey(impl.key())
    override val value: Optional[TagValue] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => zio.aws.workspaces.model.primitives.TagValue(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.Tag
  ): zio.aws.workspaces.model.Tag.ReadOnly = new Wrapper(impl)
}

==> zio-aws-workspaces_3-5.17.147.1-sources.jar: zio/aws/workspaces/model/Tag.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.{TagValue, TagKey}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Tag(key: TagKey, value: Option[TagValue] = None) {
  def buildAwsValue(): software.amazon.awssdk.services.workspaces.model.Tag = {
    import Tag.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.Tag
      .builder()
      .key(TagKey.unwrap(key): java.lang.String)
      .optionallyWith(
        value.map(value => TagValue.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly: zio.aws.workspaces.model.Tag.ReadOnly =
    zio.aws.workspaces.model.Tag.wrap(buildAwsValue())
}
object Tag {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.workspaces.model.Tag] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.Tag =
      zio.aws.workspaces.model.Tag(key, value.map(value => value))
    def key: TagKey
    def value: Option[TagValue]
    def getKey: ZIO[Any, Nothing, TagKey] = ZIO.succeed(key)
    def getValue: ZIO[Any, AwsError, TagValue] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.Tag
  ) extends zio.aws.workspaces.model.Tag.ReadOnly {
    override val key: TagKey =
      zio.aws.workspaces.model.primitives.TagKey(impl.key())
    override val value: Option[TagValue] = scala
      .Option(impl.value())
      .map(value => zio.aws.workspaces.model.primitives.TagValue(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.Tag
  ): zio.aws.workspaces.model.Tag.ReadOnly = new Wrapper(impl)
}
